==> react-image-annotate_ns_demo-4.0.44.tgz: package/LazyBrush/BrushPoup.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import CheckIcon from "@mui/icons-material/Check";
import TrashIcon from "@mui/icons-material/Delete";
import WarningAmberIcon from "@mui/icons-material/WarningAmber";
import { Button, IconButton, Paper } from "@mui/material";
import React from "react";
import CreatableSelect from "react-select/creatable";
import { asMutable } from "seamless-immutable";
import colors from "../colors";

var convertHextoRgb = function convertHextoRgb(color) {
  try {
    var hashRemove = color.replace("#", "");
    console.log(hashRemove, color);
    var aRgbHex = hashRemove.match(/.{1,2}/g);
    var aRgb = [parseInt(aRgbHex[0], 16), parseInt(aRgbHex[1], 16), parseInt(aRgbHex[2], 16)];
    console.log(aRgb);
    return aRgb.toString();
  } catch (err) {
    var aRgbHex = "FF0000".match(/.{1,2}/g);
    var aRgb = [parseInt(aRgbHex[0], 16), parseInt(aRgbHex[1], 16), parseInt(aRgbHex[2], 16)];
    return aRgb.toString();
  }
};

function BrushPopup(_ref) {
  var _lines;

  var top = _ref.top,
      left = _ref.left,
      showTags = _ref.showTags,
      lines = _ref.lines,
      lazyBrushClassification = _ref.lazyBrushClassification,
      lazyBrushTags = _ref.lazyBrushTags,
      setLines = _ref.setLines,
      scale = _ref.scale,
      invalidShow = _ref.invalidShow;
  return /*#__PURE__*/React.createElement("div", null, showTags && ((_lines = lines) === null || _lines === void 0 ? void 0 : _lines.map(function (item, index) {
    var _item$popUp, _item$popUp4, _item$popUp6, _item$popUp7, _item$popUp7$tags;

    return item.tool === "pen" && /*#__PURE__*/React.createElement("div", {
      style: {
        left: "".concat(item.points[0] * scale, "px"),
        top: "".concat(item.points[1] * scale, "px"),
        position: "absolute"
      }
    }, /*#__PURE__*/React.createElement(Paper, {
      style: {
        zIndex: 110,
        // top: `${19.166664123535156}px`,
        // left: `${197.90878098221688}px`,
        position: "absolute",
        cursor: "pointer",
        border: !invalidShow && lines[index].invaild ? "2px solid red" : null
      }
    }, item !== null && item !== void 0 && (_item$popUp = item.popUp) !== null && _item$popUp !== void 0 && _item$popUp.open ? /*#__PURE__*/React.createElement("div", {
      style: {
        width: 200,
        padding: 10
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        display: "flex",
        flexDirection: "row"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        display: "flex",
        backgroundColor: colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
          var _item$popUp2, _item$popUp2$classifi;

          return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp2 = item.popUp) === null || _item$popUp2 === void 0 ? void 0 : (_item$popUp2$classifi = _item$popUp2.classification) === null || _item$popUp2$classifi === void 0 ? void 0 : _item$popUp2$classifi.label);
        })) || 0 % colors.length] || "red",
        color: "#fff",
        padding: 4,
        paddingLeft: 8,
        paddingRight: 8,
        borderRadius: 4,
        fontWeight: "bold",
        textShadow: "0px 0px 5px rgba(0,0,0,0.4)"
      }
    }, "Brush"), /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: 1
      }
    }), /*#__PURE__*/React.createElement(IconButton, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(lines);

        linessave.splice(index, 1);
        lines = linessave;
        setLines(linessave);
      },
      tabIndex: -1,
      style: {
        width: 22,
        height: 22
      },
      size: "small",
      variant: "outlined"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      style: {
        marginTop: -8,
        width: 16,
        height: 16
      }
    })), invalidShow && /*#__PURE__*/React.createElement(WarningAmberIcon, {
      onClick: function onClick() {
        var linessave = _toConsumableArray(lines);

        lines[index].invaild = lines[index].invaild ? false : true;
        setLines(linessave);
      },
      color: lines[index].invaild ? "primary" : "secondary"
    })), /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 6
      }
    }, /*#__PURE__*/React.createElement(CreatableSelect, {
      placeholder: "Classification",
      onChange: function onChange(o, actionMeta) {
        var linessave = _toConsumableArray(lines);

        lines[index].popUp.classification = o;
        lines[index].color = "rgba(".concat(convertHextoRgb(colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
          var _item$popUp3, _item$popUp3$classifi;

          return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp3 = item.popUp) === null || _item$popUp3 === void 0 ? void 0 : (_item$popUp3$classifi = _item$popUp3.classification) === null || _item$popUp3$classifi === void 0 ? void 0 : _item$popUp3$classifi.label);
        })) || 0 % colors.length] || "#FF0000"), ",0.5)");
        setLines(linessave);
      },
      value: lines[index].popUp.classification,
      options: asMutable(lazyBrushClassification.map(function (c) {
        return {
          value: c,
          label: c
        };
      }))
    })), /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 4
      }
    }, /*#__PURE__*/React.createElement(CreatableSelect, {
      value: lines[index].popUp.tags,
      placeholder: "Tags",
      onChange: function onChange(o, actionMeta) {
        var _lines2, _lines2$index, _lines2$index$popUp, _lines2$index$popUp$t;

        var linessave = _toConsumableArray(lines);

        lines[index].popUp.tags = o;
        lines[index].tag_count = (_lines2 = lines) === null || _lines2 === void 0 ? void 0 : (_lines2$index = _lines2[index]) === null || _lines2$index === void 0 ? void 0 : (_lines2$index$popUp = _lines2$index.popUp) === null || _lines2$index$popUp === void 0 ? void 0 : (_lines2$index$popUp$t = _lines2$index$popUp.tags) === null || _lines2$index$popUp$t === void 0 ? void 0 : _lines2$index$popUp$t.length;
        setLines(linessave);
      },
      isMulti: true,
      options: asMutable(lazyBrushTags.map(function (c) {
        return {
          value: c,
          label: c
        };
      }))
    })), /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 4,
        display: "flex"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: 1
      }
    }), /*#__PURE__*/React.createElement(Button, {
      onClick: function onClick() {
        var linessave = _toConsumableArray(lines);

        lines[index].popUp.open = false;
        setLines(linessave);
      },
      size: "small",
      variant: "contained",
      color: "primary"
    }, /*#__PURE__*/React.createElement(CheckIcon, null)))) : /*#__PURE__*/React.createElement("div", {
      style: {
        padding: 8
      },
      onClick: function onClick() {
        var linessave = _toConsumableArray(lines);

        lines[index].popUp.open = true;
        var i = 0;

        for (i = 0; i < ((_lines3 = lines) === null || _lines3 === void 0 ? void 0 : _lines3.length); i++) {
          var _lines3;

          if (i !== index) {
            lines[i].popUp.open = false;
          }
        }

        setLines(linessave);
      }
    }, (item === null || item === void 0 ? void 0 : (_item$popUp4 = item.popUp) === null || _item$popUp4 === void 0 ? void 0 : _item$popUp4.classification) && /*#__PURE__*/React.createElement("div", {
      className: "name",
      style: {
        display: "flex",
        justifyContent: "space-between",
        alignItems: "center"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        backgroundColor: colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
          var _item$popUp5;

          return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp5 = item.popUp) === null || _item$popUp5 === void 0 ? void 0 : _item$popUp5.classification.label);
        })) % colors.length],
        width: 12,
        height: 12,
        borderRadius: 12,
        marginRight: 8
      }
    }), /*#__PURE__*/React.createElement("span", null, item === null || item === void 0 ? void 0 : (_item$popUp6 = item.popUp) === null || _item$popUp6 === void 0 ? void 0 : _item$popUp6.classification.label)), /*#__PURE__*/React.createElement("div", null, item === null || item === void 0 ? void 0 : (_item$popUp7 = item.popUp) === null || _item$popUp7 === void 0 ? void 0 : (_item$popUp7$tags = _item$popUp7.tags) === null || _item$popUp7$tags === void 0 ? void 0 : _item$popUp7$tags.map(function (t) {
      return /*#__PURE__*/React.createElement("div", {
        key: t.label,
        style: {
          color: "gray",
          display: "inline-block",
          margin: 1,
          fontSize: 10,
          textDecoration: "underline"
        }
      }, t.label);
    })))));
  })));
}

export default BrushPopup;

==> react-image-annotate_ns_demo-4.0.49.tgz: package/LazyBrush/BrushPoup.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import CheckIcon from "@mui/icons-material/Check";
import TrashIcon from "@mui/icons-material/Delete";
import WarningAmberIcon from "@mui/icons-material/WarningAmber";
import { Button, IconButton, Paper } from "@mui/material";
import React from "react";
import CreatableSelect from "react-select/creatable";
import { asMutable } from "seamless-immutable";
import colors from "../colors";

var convertHextoRgb = function convertHextoRgb(color) {
  try {
    var hashRemove = color.replace("#", "");
    console.log(hashRemove, color);
    var aRgbHex = hashRemove.match(/.{1,2}/g);
    var aRgb = [parseInt(aRgbHex[0], 16), parseInt(aRgbHex[1], 16), parseInt(aRgbHex[2], 16)];
    console.log(aRgb);
    return aRgb.toString();
  } catch (err) {
    var aRgbHex = "FF0000".match(/.{1,2}/g);
    var aRgb = [parseInt(aRgbHex[0], 16), parseInt(aRgbHex[1], 16), parseInt(aRgbHex[2], 16)];
    return aRgb.toString();
  }
};

function BrushPopup(_ref) {
  var _lines;

  var top = _ref.top,
      left = _ref.left,
      showTags = _ref.showTags,
      lines = _ref.lines,
      lazyBrushClassification = _ref.lazyBrushClassification,
      lazyBrushTags = _ref.lazyBrushTags,
      setLines = _ref.setLines,
      scale = _ref.scale,
      invalidShow = _ref.invalidShow,
      delete_annotation = _ref.delete_annotation,
      setdelete_annotation = _ref.setdelete_annotation;
  return /*#__PURE__*/React.createElement("div", null, showTags && ((_lines = lines) === null || _lines === void 0 ? void 0 : _lines.map(function (item, index) {
    var _item$popUp, _item$popUp4, _item$popUp6, _item$popUp7, _item$popUp7$tags;

    return item.tool === "pen" && /*#__PURE__*/React.createElement("div", {
      style: {
        left: "".concat(item.points[0] * scale, "px"),
        top: "".concat(item.points[1] * scale, "px"),
        position: "absolute"
      }
    }, /*#__PURE__*/React.createElement(Paper, {
      style: {
        zIndex: 110,
        // top: `${19.166664123535156}px`,
        // left: `${197.90878098221688}px`,
        position: "absolute",
        cursor: "pointer",
        border: !invalidShow && lines[index].invaild ? "2px solid red" : null
      }
    }, item !== null && item !== void 0 && (_item$popUp = item.popUp) !== null && _item$popUp !== void 0 && _item$popUp.open ? /*#__PURE__*/React.createElement("div", {
      style: {
        width: 200,
        padding: 10
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        display: "flex",
        flexDirection: "row"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        display: "flex",
        backgroundColor: colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
          var _item$popUp2, _item$popUp2$classifi;

          return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp2 = item.popUp) === null || _item$popUp2 === void 0 ? void 0 : (_item$popUp2$classifi = _item$popUp2.classification) === null || _item$popUp2$classifi === void 0 ? void 0 : _item$popUp2$classifi.label);
        })) || 0 % colors.length] || "red",
        color: "#fff",
        padding: 4,
        paddingLeft: 8,
        paddingRight: 8,
        borderRadius: 4,
        fontWeight: "bold",
        textShadow: "0px 0px 5px rgba(0,0,0,0.4)"
      }
    }, "Brush"), /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: 1
      }
    }), /*#__PURE__*/React.createElement(IconButton, {
      onClick: function onClick(e) {
        var linessave = _toConsumableArray(lines);

        linessave.splice(index, 1);
        lines = linessave;
        setLines(linessave);

        var arr = _toConsumableArray(delete_annotation);

        arr.push(item);
        setdelete_annotation(arr);
      },
      tabIndex: -1,
      style: {
        width: 22,
        height: 22
      },
      size: "small",
      variant: "outlined"
    }, /*#__PURE__*/React.createElement(TrashIcon, {
      style: {
        marginTop: -8,
        width: 16,
        height: 16
      }
    })), invalidShow && /*#__PURE__*/React.createElement(WarningAmberIcon, {
      onClick: function onClick() {
        var linessave = _toConsumableArray(lines);

        lines[index].invaild = lines[index].invaild ? false : true;
        setLines(linessave);
      },
      style: {
        color: lines[index].invaild ? "#faad14" : "grey"
      } // color={
      //   lines[index].invaild ? "primary" : "secondary"
      // }

    })), /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 6
      }
    }, /*#__PURE__*/React.createElement(CreatableSelect, {
      placeholder: "Classification",
      onChange: function onChange(o, actionMeta) {
        var linessave = _toConsumableArray(lines);

        lines[index].popUp.classification = o;
        lines[index].color = "rgba(".concat(convertHextoRgb(colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
          var _item$popUp3, _item$popUp3$classifi;

          return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp3 = item.popUp) === null || _item$popUp3 === void 0 ? void 0 : (_item$popUp3$classifi = _item$popUp3.classification) === null || _item$popUp3$classifi === void 0 ? void 0 : _item$popUp3$classifi.label);
        })) || 0 % colors.length] || "#FF0000"), ",0.5)");
        setLines(linessave);
      },
      value: lines[index].popUp.classification,
      options: asMutable(lazyBrushClassification.map(function (c) {
        return {
          value: c,
          label: c
        };
      }))
    })), /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 4
      }
    }, /*#__PURE__*/React.createElement(CreatableSelect, {
      value: lines[index].popUp.tags,
      placeholder: "Tags",
      onChange: function onChange(o, actionMeta) {
        var _lines2, _lines2$index, _lines2$index$popUp, _lines2$index$popUp$t;

        var linessave = _toConsumableArray(lines);

        lines[index].popUp.tags = o;
        lines[index].tag_count = (_lines2 = lines) === null || _lines2 === void 0 ? void 0 : (_lines2$index = _lines2[index]) === null || _lines2$index === void 0 ? void 0 : (_lines2$index$popUp = _lines2$index.popUp) === null || _lines2$index$popUp === void 0 ? void 0 : (_lines2$index$popUp$t = _lines2$index$popUp.tags) === null || _lines2$index$popUp$t === void 0 ? void 0 : _lines2$index$popUp$t.length;
        setLines(linessave);
      },
      isMulti: true,
      options: asMutable(lazyBrushTags.map(function (c) {
        return {
          value: c,
          label: c
        };
      }))
    })), /*#__PURE__*/React.createElement("div", {
      style: {
        marginTop: 4,
        display: "flex"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        flexGrow: 1
      }
    }), /*#__PURE__*/React.createElement(Button, {
      onClick: function onClick() {
        var linessave = _toConsumableArray(lines);

        lines[index].popUp.open = false;
        setLines(linessave);
      },
      size: "small",
      variant: "contained",
      color: "primary"
    }, /*#__PURE__*/React.createElement(CheckIcon, null)))) : /*#__PURE__*/React.createElement("div", {
      style: {
        padding: 8
      },
      onClick: function onClick() {
        var linessave = _toConsumableArray(lines);

        lines[index].popUp.open = true;
        var i = 0;

        for (i = 0; i < ((_lines3 = lines) === null || _lines3 === void 0 ? void 0 : _lines3.length); i++) {
          var _lines3;

          if (i !== index) {
            lines[i].popUp.open = false;
          }
        }

        setLines(linessave);
      }
    }, (item === null || item === void 0 ? void 0 : (_item$popUp4 = item.popUp) === null || _item$popUp4 === void 0 ? void 0 : _item$popUp4.classification) && /*#__PURE__*/React.createElement("div", {
      className: "name",
      style: {
        display: "flex",
        justifyContent: "space-between",
        alignItems: "center"
      }
    }, /*#__PURE__*/React.createElement("div", {
      style: {
        backgroundColor: colors[(lazyBrushClassification === null || lazyBrushClassification === void 0 ? void 0 : lazyBrushClassification.findIndex(function (dropdown) {
          var _item$popUp5;

          return dropdown === (item === null || item === void 0 ? void 0 : (_item$popUp5 = item.popUp) === null || _item$popUp5 === void 0 ? void 0 : _item$popUp5.classification.label);
        })) % colors.length],
        width: 12,
        height: 12,
        borderRadius: 12,
        marginRight: 8
      }
    }), /*#__PURE__*/React.createElement("span", null, item === null || item === void 0 ? void 0 : (_item$popUp6 = item.popUp) === null || _item$popUp6 === void 0 ? void 0 : _item$popUp6.classification.label)), /*#__PURE__*/React.createElement("div", null, item === null || item === void 0 ? void 0 : (_item$popUp7 = item.popUp) === null || _item$popUp7 === void 0 ? void 0 : (_item$popUp7$tags = _item$popUp7.tags) === null || _item$popUp7$tags === void 0 ? void 0 : _item$popUp7$tags.map(function (t) {
      return /*#__PURE__*/React.createElement("div", {
        key: t.label,
        style: {
          color: "gray",
          display: "inline-block",
          margin: 1,
          fontSize: 10,
          textDecoration: "underline"
        }
      }, t.label);
    })))));
  })));
}

export default BrushPopup;
